==> borealis-7.x-1.0-rc5.tar.gz: borealis/borealis_ri/js/borealis_ri.js <==
jQuery(document).ready(function() {
  $ = jQuery;
  
  var settings = Drupal.settings.borealis_ri.sizes;
  var settingsArray = sortObject(settings);
  var settingArrayLength = settingsArray.length;
  
  var sizeArray = new Array();
  var styleArray = new Array();
  for (i = 0; i < settingArrayLength; i++) {
    sizeArray.push(settingsArray[i].value);
    styleArray.push(settingsArray[i].key);
  }
  
  Drupal.settings.borealis_ri.sizeArray = sizeArray;
  Drupal.settings.borealis_ri.styleArray = styleArray;
  
  // var i = 0;
  // $.each(settings, function(index, value) {
  // });
  // 
  // Remove height/width attributes from img.borealis
  $('img.borealis').each(function() {
    $(this).removeAttr('height');
    $(this).removeAttr('width');
  });
  
  // Call borealisImageRespond to initialize the images!
  borealisImageRespond();
  
  // When the screen is resized, check again!
  $(window).resize(function() {
    borealisImageRespond();
  });
});

//////////////////////////////
// Borealis Responsive Images
//
// Loop over each image, and change their source depending on parent width
// We swap the next size images in at 90% of the current image's actual width to help 
//  ensure a smooth flow between images by allowing for a buffer between sizes.
//////////////////////////////
function borealisImageRespond() {
  
  var sizeArray = Drupal.settings.borealis_ri.sizeArray;
  var styleArray = Drupal.settings.borealis_ri.styleArray;
  var arraySize = sizeArray.length;
  var dpr = (window.devicePixelRatio !== undefined) ? window.devicePixelRatio : 1;
  var swapped = false;
  
  
  $('img.borealis').each(function() {
    var width = blockParentWidth($(this));
    
    var imgStyle = $(this).attr('data-borealis-style') ? $(this).attr('data-borealis-style') : styleArray[0];
    
    if (width > 0) {
      var slfor = arraySize - 1;
      
      for (j = slfor; j >= 0; j--) {
        
        if (j != 0) {
          if (width >= (sizeArray[j-1])) {
            if (j == slfor) {
              console.log('You need larger sizes! Increase your minimum size!')
            }
            else if (dpr > 1 && dpr <= 2) {
              if (j+1 > styleArray.indexOf(imgStyle)) {
                $(this).attr('src', $(this).attr('data-borealis-' + styleArray[j]));
                $(this).attr('data-borealis-style', styleArray[j]);
                return;
              }
              else {
                return;
              }
            }
            else {
              if (j > styleArray.indexOf(imgStyle)) {
                $(this).attr('src', $(this).attr('data-borealis-' + styleArray[j-1]));
                $(this).attr('data-borealis-style', styleArray[j-1]);
                return;
              }
              else {
                return;
              }
            }
          }
        }
        // If j == 0
        else {
          if (!swapped) {
            if (dpr > 1 && dpr <= 2) {
              $(this).attr('src', $(this).attr('data-borealis-' + styleArray[j+1]));
              $(this).attr('data-borealis-style', styleArray[j+1]);
              return;
            }
            else {
              $(this).attr('src', $(this).attr('data-borealis-' + styleArray[j]));
              $(this).attr('data-borealis-style', styleArray[j]);
              return;
            }
          }
        }
      }
    }
  });
}

//////////////////////////////
// Returns the width of the nearest non-inline parent.
//////////////////////////////
function blockParentWidth(element) {
  var parentDisplay = element.parent().css('display');
  
  if (parentDisplay.indexOf('inline') >= 0 && parentDisplay.indexOf('block') < 0) {
    return blockParentWidth(element.parent());
  }
  else {
    return element.parent().width();
  }
}

//////////////////////////////
// Sorts an object into an array by value. http://stackoverflow.com/questions/1069666/sorting-javascript-object-by-property-value
//////////////////////////////
function sortObject(obj) {
    var arr = new Array();
    for (attr in obj) {
        arr.push({
            'key': attr,
            'value': obj[attr]
        });
    }
    arr.sort(function(a, b) { return a['value'] - b['value'] });
    return arr; // returns array
}

==> borealis-7.x-1.1.tar.gz: borealis/borealis_ri/js/borealis_ri.js <==
jQuery(document).ready(function() {
  $ = jQuery;

  var settings = Drupal.settings.borealis_ri.sizes;
  var settingsArray = sortObject(settings);
  var settingArrayLength = settingsArray.length;

  var sizeArray = new Array();
  var styleArray = new Array();
  for (i = 0; i < settingArrayLength; i++) {
    sizeArray.push(settingsArray[i].value);
    styleArray.push(settingsArray[i].key);
  }

  Drupal.settings.borealis_ri.sizeArray = sizeArray;
  Drupal.settings.borealis_ri.styleArray = styleArray;

  // var i = 0;
  // $.each(settings, function(index, value) {
  // });
  //
  // Remove height/width attributes from img.borealis
  $('img.borealis').each(function() {
    $(this).removeAttr('height');
    $(this).removeAttr('width');
  });

  // Call borealisImageRespond to initialize the images!
  borealisImageRespond();

  // When the screen is resized, check again!
  $(window).resize(function() {
    borealisImageRespond();
  });
});

//////////////////////////////
// Add indexOf Polyfill
//
// indexOf is new to ECMA-262 standard and as such, if it doesn't exist, we need to polyfill for it.
// Polyfill from https://developer.mozilla.org/en-US/docs/JavaScript/Reference/Global_Objects/Array/indexOf#Compatibility
//////////////////////////////
if (!Array.prototype.indexOf) {
  Array.prototype.indexOf = function (searchElement /*, fromIndex */ ) {
    "use strict";
    if (this == null) {
      throw new TypeError();
    }
    var t = Object(this);
    var len = t.length >>> 0;
    if (len === 0) {
      return -1;
    }
    var n = 0;
    if (arguments.length > 1) {
      n = Number(arguments[1]);
      if (n != n) { // shortcut for verifying if it's NaN
          n = 0;
      } else if (n != 0 && n != Infinity && n != -Infinity) {
          n = (n > 0 || -1) * Math.floor(Math.abs(n));
      }
    }
    if (n >= len) {
      return -1;
    }
    var k = n >= 0 ? n : Math.max(len - Math.abs(n), 0);
    for (; k < len; k++) {
      if (k in t && t[k] === searchElement) {
          return k;
      }
    }
    return -1;
  }
}

//////////////////////////////
// Borealis Responsive Images
//
// Loop over each image, and change their source depending on parent width
// We swap the next size images in at 90% of the current image's actual width to help
//  ensure a smooth flow between images by allowing for a buffer between sizes.
//////////////////////////////
function borealisImageRespond() {

  var sizeArray = Drupal.settings.borealis_ri.sizeArray;
  var styleArray = Drupal.settings.borealis_ri.styleArray;
  var arraySize = sizeArray.length;
  var dpr = (window.devicePixelRatio !== undefined) ? window.devicePixelRatio : 1;
  var swapped = false;


  $('img.borealis').each(function() {
    var width = blockParentWidth($(this));

    var imgStyle = $(this).attr('data-borealis-style') ? $(this).attr('data-borealis-style') : styleArray[0];

    if (width > 0) {
      var slfor = arraySize - 1;

      for (j = slfor; j >= 0; j--) {

        if (j != 0) {
          if (width >= (sizeArray[j-1])) {
            if (j == slfor) {
              // Set to the largest possible file we've got
              $(this).attr('src', $(this).attr('data-borealis-' + styleArray[j+1]));
              $(this).attr('data-borealis-style', styleArray[j+1]);
            }
            // Use steped up image for high resolution displays
            else if (dpr > 1.5 && dpr <= 2.5) {
              if (j+1 > styleArray.indexOf(imgStyle)) {
                $(this).attr('src', $(this).attr('data-borealis-' + styleArray[j+1]));
                $(this).attr('data-borealis-style', styleArray[j+1]);
                return;
              }
              else {
                return;
              }
            }
            // Use single sized image
            else {
              if (j > styleArray.indexOf(imgStyle)) {
                $(this).attr('src', $(this).attr('data-borealis-' + styleArray[j]));
                $(this).attr('data-borealis-style', styleArray[j]);
                return;
              }
              else {
                return;
              }
            }
          }
        }
        // If j == 0
        else {
          if (!swapped) {
            if (dpr > 1.5 && dpr <= 2.5) {
              $(this).attr('src', $(this).attr('data-borealis-' + styleArray[j+1]));
              $(this).attr('data-borealis-style', styleArray[j+1]);
              return;
            }
            else {
              $(this).attr('src', $(this).attr('data-borealis-' + styleArray[j]));
              $(this).attr('data-borealis-style', styleArray[j]);
              return;
            }
          }
        }
      }
    }
  });
}

//////////////////////////////
// Returns the width of the nearest non-inline parent.
//////////////////////////////
function blockParentWidth(element) {
  var parentDisplay = element.parent().css('display');

  if (parentDisplay.indexOf('inline') >= 0 && parentDisplay.indexOf('block') < 0) {
    return blockParentWidth(element.parent());
  }
  else {
    return element.parent().width();
  }
}

//////////////////////////////
// Sorts an object into an array by value. http://stackoverflow.com/questions/1069666/sorting-javascript-object-by-property-value
//////////////////////////////
function sortObject(obj) {
    var arr = new Array();
    for (attr in obj) {
        arr.push({
            'key': attr,
            'value': obj[attr]
        });
    }
    arr.sort(function(a, b) { return a['value'] - b['value'] });
    return arr; // returns array
}
